package Acme::CogIsExperimenting;

use Acme::CogIsExperimentingMore;

use warnings;
use strict;

=head1 NAME

Acme::CogIsExperimenting - Cog's experiments

=head1 VERSION

Version 0.01

=cut

our $VERSION = '0.01';

=head1 SYNOPSIS

Move along, nothing to see here.

=head1 CURRENT EXPERIMENTS

What happens when two modules use each other? Does CPAN install them alright?
Does CPANPLUS does the trick? Something else, perhaps?

We're about to find out...

=cut

sub _function1 {
  return 1;
}

sub _function2 {
  return 2;
}

=head1 AUTHOR

Jose Castro, C<< <cog@cpan.org> >>

=head1 BUGS

Please report any bugs or feature requests to
C<bug-acme-cogisexperimenting@rt.cpan.org>, or through the web interface at
L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Acme-CogIsExperimenting>.
I will be notified, and then you'll automatically be notified of progress on
your bug as I make changes.

=head1 ACKNOWLEDGEMENTS

=head1 COPYRIGHT & LICENSE

Copyright 2005 Jose Castro, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

=cut

1; # End of Acme::CogIsExperimenting
